<?php
/*
Plugin Name: Genesis Post Teasers
Plugin URI: http://genesistutorials.com/plug-ins/genesis-post-teasers/
Description: Add theme settings for enabling teasers for the Genesis Theme Framework by studiopress. Uses genesis_grid_loop();
Version: 2.0.3
Author: Christopher Cochran
Author URI: http://christophercochran.me
*/

class Genesis_Post_Teasers {

	protected $teasers_on,
	          $full_posts,
	          $teaser_posts;

	public function __construct() {

		$this->full_posts   = false;
		$this->teaser_posts = false;
		$this->teasers_on   = false;

		add_filter( 'genesis_theme_settings_defaults', array( &$this, 'define_default_settings'), 15, 2 );
		add_action( 'genesis_init',                    array( &$this, 'init'                   ), 15    );
		add_action( 'get_header',                      array( &$this, 'enable_logic'           )        );

		add_action( 'pre_get_posts',  array( &$this, 'query' ) );

	}

	public static function activate() {

	    $theme_info = wp_get_theme();

		$genesis_flavors = array(
			'genesis',
			'genesis-trunk',
		);

        if ( ! in_array( $theme_info->Template, $genesis_flavors ) ) {
            deactivate_plugins( plugin_basename(__FILE__) ); // Deactivate ourself
	        wp_die( 'Sorry, you are not able to activate this plugin unless you have installed <a href="http://www.studiopress.com/themes/genesis">Genesis</a>' );
        }

	}

	public function loop_count() {
		global $wp_query;
		return $wp_query->current_post;
	}

	public function posts_size() {
		global $wp_query;
		return sizeof( $wp_query->posts );
	}

	public function init() {

		add_action( 'admin_menu',  array( &$this, 'settings_init' ) );

	}

	public function settings_init() {
	global $_genesis_theme_settings_pagehook;

		add_action( 'genesis_theme_settings_metaboxes',  array( &$this, 'settings_boxes'   ) );
		add_action( 'genesis_theme_settings_metaboxes',  array( &$this, 'settings_scripts' ) );

	}

	public function settings_scripts() {

		wp_enqueue_script(
			'settingslide',
			WP_PLUGIN_URL . '/genesis-post-teasers/js/settingslide.js'
		);

	}

	function settings_boxes() {
	global $_genesis_theme_settings_pagehook;

		add_meta_box( 'gPostTeaz-settings-box', 'Teaser Boxes Settings', array( &$this, 'settings_box' ), $_genesis_theme_settings_pagehook, 'column2', 'high' );

	}

	public function settings_box() {

		include 'gpt-meta-box.php';

	}

	public function define_default_settings( $defaults ) {

		$defaults = array(
			'teasers_enable'           => 'Home Page',
			'numof_posts_per_page'     => 10,
			'use_css'                  => 'pluginstyles',
			'numof_full_posts'         => 2,
			'readmore_link_on_teasers' => '[Continue reading...]'
		);

    	return $defaults;
	}

	// All the logic to make it happen.
	public function enable_logic() {

		if ( ! function_exists( 'genesis' ) )
			return;

		$this->full_posts   = genesis_get_option( 'numof_full_posts' );
		$this->teaser_posts = $this->posts_size() - $this->full_posts;

		if ( $this->teasers_on ) {

			remove_action( 'genesis_loop', 'genesis_do_loop' );
			remove_action( 'genesis_loop', 'focus_grid_loop_helper' );
			remove_action( 'genesis_loop', 'pretty_grid_loop_helper' );

			add_action( 'genesis_loop', array( &$this, 'grid_loop' ) );

			add_action( 'genesis_before_post', array( &$this, 'container_open' ), 1 );

			// HTML5
			add_action( 'genesis_before_entry', array( &$this, 'container_open' ), 10 );

			if ( genesis_get_option( 'no_pair_teasers' ) == 0 ) {

				add_action( 'genesis_before_post',    array( &$this, 'row_wrap_open'        ), 5  );
				add_action( 'genesis_after_post',     array( &$this, 'row_wrap_closeopen'   ), 15 );
				add_action( 'genesis_after_post',     array( &$this, 'row_wrap_close'       ), 15 );

				// HTML5
				add_action( 'genesis_before_entry',    array( &$this, 'row_wrap_open'       ), 15 );
				add_action( 'genesis_after_entry',     array( &$this, 'row_wrap_closeopen'  )     );
				add_action( 'genesis_after_entry',     array( &$this, 'row_wrap_close'      )     );

			}

			add_action( 'genesis_after_endwhile', array( &$this, 'container_close' ), 1 );

			if ( genesis_get_option( 'no_pair_teasers' ) == 1 || genesis_get_option( 'use_css' ) == 'pluginstyles'  ) {

				$genesis                         = $this->full_posts;
				$genesisopt_full_width           = genesis_get_option( 'no_pair_teasers'             );
				$genesisopt_width                = genesis_get_option( 'post_teaser_width'           );
				$genesisopt_height               = genesis_get_option( 'post_teaser_height'          );
				$genesisopt_enable_custom_styles = genesis_get_option( 'enable_custom_teaser_styles' );

				wp_enqueue_style(
					'teaserstyles',
					WP_PLUGIN_URL . "/genesis-post-teasers/css/teaserstyles.php?genesis=$genesis&genesisopt_width=$genesisopt_width&genesisopt_height=$genesisopt_height&genesisopt_no_pair=$genesisopt_full_width&genesisopt_enable_custom_styles=$genesisopt_enable_custom_styles"
				);

			}

			if ( genesis_get_option( 'disable_teaser_meta' ) == 1 ) {

				remove_action( 'genesis_after_post_content', 'genesis_post_meta' );

				add_action( 'genesis_after_post_content', array( &$this, 'post_meta_logic' ) );


				// HTML5
				remove_action( 'genesis_entry_footer', 'genesis_post_meta' );

				add_action( 'genesis_entry_footer', array( &$this, 'post_meta_logic' ) );

			}

			if ( genesis_get_option( 'disable_teaser_info' ) == 1 ) {

				remove_action( 'genesis_before_post_content', 'genesis_post_info' );

				add_action( 'genesis_before_post_content', array( &$this, 'post_info_logic' ) );


				// HTML5
				remove_action( 'genesis_entry_header', 'genesis_post_info', 12 );

				add_action( 'genesis_entry_header', array( &$this, 'post_info_logic' ), 12 );

			}

		}

	}


	// Wraps the post teaser area with its own div.
	public function container_open() {

		if ( !is_paged() && $this->loop_count() == $this->full_posts || is_paged() >= 2 && $this->loop_count() == 0 )
			echo '<div id="post-teasers">';

	}


		//Opens the div for the first pair of teasers. This helps to keep the area of two
		//the same height so can have a flexible height for the teasers.
		public function row_wrap_open() {

			if ( !is_paged() && $this->loop_count() == $this->full_posts || is_paged() >= 2 && $this->loop_count() == 0)
				echo '<div class="post-teasers-row post-teasers-pair">';

		}

		// Wraps the a pair of teasers with their own div. This helps to keep the area of two
		//the same height so can have a flexible height for the teasers.
		public function row_wrap_closeopen() {

			if ( $this->loop_count() == ( get_option( 'posts_per_page' ) - 1 ) || $this->loop_count() == genesis_get_option( 'numof_posts_per_page' ) )
				return;

			if ( !is_paged() && $this->loop_count() >= $this->full_posts && ( $this->loop_count() - $this->full_posts ) % 2 && $this->loop_count() < ( $this->posts_size() - 1 ) || is_paged() >= 2 && ( $this->loop_count() + 1 ) % 2 == 0 && $this->loop_count() !== ( $this->posts_size() - 1 ) ) {
				// echo '</div><!-- end pair-' . ( ( $this->loop_count() + 1 ) / 2 ) . ' --><!-- start pair-' . ( ( $this->loop_count() + 1 ) / 2 + 1 ) . ' --><div class="post-teasers-row post-teasers-pair">';
				echo '</div><div class="post-teasers-row post-teasers-pair">';
			}

		}

		// Closing div to teaser pairs.
		public function row_wrap_close() {

			if ( $this->teaser_posts == 0 && !is_paged() )
				return; // Do not close since there is no open! Props @GK.

			if ( $this->loop_count() == ( $this->posts_size() - 1 ) ) {
				// echo '</div><!-- end last pair-' . ( ( $this->loop_count() + 1 ) / 2 ) . ' -->';
				echo '</div>';
			}

		}

	// Closing div to post teaser area.
	public function container_close() {

		if ( $this->teaser_posts == 0 && !is_paged() )
			return; // Do not close since there is no open! Props @GK.

		echo '</div>';

	}

	// This will remove post meta on teaser posts
	public function post_meta_logic() {

		if ( $this->loop_count() >= $this->full_posts || is_paged() >= 2 )
			return; // don't do post-meta on teasers

		genesis_post_meta();

	}

	// This will remove post info on teaser posts
	public function post_info_logic() {

		if ( $this->loop_count() >= $this->full_posts || is_paged() >= 2 )
			return; // don't do post-info on teasers

		genesis_post_info();

	}

	function query( $query ) {

		if ( ! function_exists( 'genesis_get_option' ) )
			return;

		if ( genesis_get_option( 'teasers_enable' ) == 'Home Page' )
			$this->teasers_on = is_home();

		if ( genesis_get_option( 'teasers_enable' ) == 'Blog Template' )
			$this->teasers_on = ( get_post_meta( $query->get('page_id'), '_wp_page_template', true ) == 'page_blog.php' ? true : false );

		if ( genesis_get_option( 'teasers_enable' ) == 'Archives' )
			$this->teasers_on = is_archive();

		if ( genesis_get_option( 'numof_posts_per_page' ) )
			$postperpage = genesis_get_option( 'numof_posts_per_page' );

		if( $query->is_main_query() && $this->teasers_on )
			$query->set( 'posts_per_page', $postperpage );

	}

	// Using The Grid Loop Now.
	public function grid_loop() {

		$feat_image_size = '';
		$grid_image_size = '';
		$cat_id          = '';
		$tag_id          = '';
		$continuereading = __( '[Continue reading...]', 'genesis' );

		if ( genesis_get_option( 'gpt_enable_featured_thumbnail') )
			$feat_image_size = genesis_get_option( 'gpt_thumbnail_featured_size' );

		if ( genesis_get_option( 'enable_teaser_thumbnail' ) )
			$grid_image_size = genesis_get_option( 'teaser_thumbnail_size' );

		if ( genesis_get_option( 'readmore_link_on_teasers' ) )
			$continuereading = genesis_get_option( 'readmore_link_on_teasers' );

		if ( genesis_get_option( 'teasers_enable' ) == 'Blog Template' ) {

			global $wp_query, $more;

			$defaults = array();

			$include = genesis_get_option( 'blog_cat' );
			$exclude = genesis_get_option( 'blog_cat_exclude' ) ? explode( ',', str_replace( ' ', '', genesis_get_option( 'blog_cat_exclude' ) ) ) : '';
			$paged   = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : 1;

			$query_args = wp_parse_args(
				genesis_get_custom_field( 'query_args' ),
				array(
					'cat'              => $include,
					'category__not_in' => $exclude,
					'showposts'        => genesis_get_option( 'numof_posts_per_page' ),
					'paged'            => $paged,
				)
			);


			$wp_query = new WP_Query( $query_args );

			$this->teaser_posts = $this->posts_size() - $this->full_posts;

		}

		if ( genesis_get_option( 'teasers_enable' ) == 'Archives' ) {

			$cat_id = get_query_var( 'cat' );
			$tag_id = get_query_var( 'tag' );

		}

		if ( function_exists( 'genesis_grid_loop' ) ) :

		   genesis_grid_loop( array(
				'features'              => $this->full_posts,
				'feature_image_size'    => $feat_image_size,
				'feature_content_limit' => genesis_get_option( 'featured_post_content_limit' ),
				'grid_image_size'       => $grid_image_size,
				'grid_content_limit'    => genesis_get_option( 'teaser_post_content_limit' ),
				'more'                  => $continuereading,
				'cat'                   => $cat_id,
				'tag'                   => $tag_id
			) );

		else:

			genesis_standard_loop();

		endif;

		// Restore original query for Blog Template
		if ( genesis_get_option( 'teasers_enable' ) == 'Blog Template' )
			wp_reset_query();
	}

}

if ( class_exists( 'Genesis_Post_Teasers' ) ) {

	register_activation_hook( __FILE__, array( 'Genesis_Post_Teasers', 'activate' ) );

	// initiate
	$gensis_post_teasers = new Genesis_Post_Teasers();

}